---
hide-toc: true
---

# Furo

A clean customisable Sphinx documentation theme.

```{include} ../README.md
:start-after: <!-- start elevator-pitch -->
:end-before: <!-- end elevator-pitch -->
```

```{toctree}
:hidden:

quickstart
customisation/index
reference/index
recommendations
```

```{toctree}
:caption: Development
:hidden:

contributing/index
kitchen-sink/index
stability
changelog
license
```
